class Tio < Formula
  desc "Simple TTY terminal I/O application"
  homepage "https://tio.github.io"
  url "https://github.com/tio/tio/releases/download/v3.7/tio-3.7.tar.xz"
  sha256 "dbaef5dc6849229ce4eb474d4de77a7302cd2b0657731a8df86a44dd359e6afb"
  license "GPL-2.0-or-later"
  head "https://github.com/tio/tio.git", branch: "master"

  depends_on "meson" => :build
  depends_on "ninja" => :build
  depends_on "pkg-config" => :build
  depends_on "gettext"
  depends_on "glib"
  depends_on "lua"

  # fix function name conflict with system `send()`
  # upstream bug report, https://github.com/tio/tio/issues/278
  patch :DATA

  def install
    system "meson", "setup", "build", "-Dbashcompletiondir=#{bash_completion}", *std_meson_args
    system "meson", "compile", "-C", "build", "--verbose"
    system "meson", "install", "-C", "build"
  end

  test do
    # Test that tio emits the correct error output when run with an argument that is not a tty.
    # Use `script` to run tio with its stdio attached to a PTY, otherwise it will complain about that instead.
    expected = "Error: Not a tty device"
    output = if OS.mac?
      shell_output("script -q /dev/null #{bin}/tio /dev/null", 1).strip
    else
      shell_output("script -q /dev/null -e -c \"#{bin}/tio /dev/null\"", 1).strip
    end
    assert_match expected, output
  end
end

__END__
diff --git a/src/script.c b/src/script.c
index 46e6c4e..bfac3d9 100644
--- a/src/script.c
+++ b/src/script.c
@@ -181,7 +181,7 @@ static int modem_send(lua_State *L)
 }

 // lua: send(string)
-static int send(lua_State *L)
+static int send_lua(lua_State *L)
 {
     const char *string = lua_tostring(L, 1);
     int ret;
@@ -455,7 +455,7 @@ static const struct luaL_Reg tio_lib[] =
     { "msleep", msleep},
     { "line_set", line_set},
     { "modem_send", modem_send},
-    { "send", send},
+    { "send", send_lua},
     { "read", read_string},
     { "expect", expect},
     { "exit", exit_},
